Hook Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

A |
| addLegendRowHooks, $.jqplot.$.jqplot
E |
| eventListenerHooks, $.jqplot.$.jqplot
J |
| jqPlot Pugin Hooks, $.jqplot
P |
| postDrawHooks, $.jqplot.$.jqplot
| postDrawSeriesHooks, $.jqplot.$.jqplot
| postDrawSeriesShadowHooks, $.jqplot.$.jqplot
| postInitHooks, $.jqplot.$.jqplot
| postParseOptionsHooks, $.jqplot.$.jqplot
| postParseSeriesOptionsHooks, $.jqplot.$.jqplot
| postSeriesInitHooks, $.jqplot.$.jqplot
| preDrawHooks, $.jqplot.$.jqplot
| preDrawLegendHooks, $.jqplot.$.jqplot
| preDrawSeriesHooks, $.jqplot.$.jqplot
| preDrawSeriesShadowHooks, $.jqplot.$.jqplot
| preInitHooks, $.jqplot.$.jqplot
| preParseOptionsHooks, $.jqplot.$.jqplot
| preParseSeriesOptionsHooks, $.jqplot.$.jqplot
| preSeriesInitHooks, $.jqplot.$.jqplot

called at the end of legend draw, so plugins can add rows to the legend table.
called at the end of plot drawing, binds listeners to the event canvas which lays on top of the grid area.
called after plot draw.
called after each series is drawn.
called after series shadows are drawn.
called after initialization.
called after user options are parsed.
called after series related options are parsed.
called after series is initialized.
called before plot draw.
called before the legend is drawn.
called before each series is drawn.
called before series shadows are drawn.
called before initialization.
called before user options are parsed.
called before series related options are parsed.
called before series is initialized.
Close